"use client";

import Image from "next/image";

import { motion } from "framer-motion";
import { useTranslations } from "next-intl";

import { Card } from "@/components/ui/card";
import { Locale } from "@/i18n/routing";

export interface CategoryItemProps {
	icon: string;
	title: string;
	count: number;
	isMain?: boolean;
	locale: Locale;
	animate?: boolean;
	index?: number;
}

export function CategoryItem({
	icon,
	title,
	count,
	isMain,
	locale,
	index = 0,
}: CategoryItemProps) {
	const isRTL = locale === "ar";

	const t = useTranslations("Navigation");

	const MotionCard = motion(Card);

	// Animation variants
	const cardVariants = {
		hidden: { opacity: 0, y: 20 },
		visible: {
			opacity: 1,
			y: 0,
			transition: {
				type: "spring",
				stiffness: 100,
				damping: 10,
				delay: index * 0.1,
			},
		},
	};

	const iconVariants = {
		hidden: { scale: 0, opacity: 0 },
		visible: {
			scale: 1,
			opacity: 1,
			transition: {
				type: "spring",
				stiffness: 260,
				damping: 20,
				delay: index * 0.1 + 0.2,
			},
		},
	};

	const textVariants = {
		hidden: { opacity: 0, x: isRTL ? 20 : -20 },
		visible: {
			opacity: 1,
			x: 0,
			transition: {
				type: "spring",
				stiffness: 100,
				damping: 10,
				delay: index * 0.1 + 0.1,
			},
		},
	};

	return (
		<MotionCard
			className={`flex h-[60px] cursor-pointer items-center justify-between rounded-full px-4 py-2 transition-all hover:shadow-lg md:h-[78px] md:px-6 md:py-4 ${isMain ? "bg-[#2895C8] text-white" : "bg-white hover:bg-gray-50"
				}`}
			variants={cardVariants}
			initial="hidden"
			animate="visible"
			whileHover={{ scale: 1.05 }}
		>
			<motion.div
				className={`flex h-[40px] w-[40px] items-center justify-center rounded-full md:h-[54px] md:w-[54px] ${isMain ? "bg-white" : "bg-[#2895C8]"
					}`}
				variants={iconVariants}
			>
				<Image
					src={icon}
					alt={title}
					width={25}
					height={25}
					className={isMain ? "text-blue-500" : "text-white"}
				/>
			</motion.div>
			<motion.div
				className={"flex flex-col items-end"}
				variants={textVariants}
			>
				<span
					className={"mb-1 text-xs text-gray-500 md:text-sm"}
				>
					{count} {t("product")}
				</span>
				<span className="text-[15px] font-medium">{title}</span>
			</motion.div>
		</MotionCard>
	);
}
